Onegov Foundation
=================

Provides a base for Zurb Foundation themes used in OneGov.

Run the Tests
-------------
    
Install tox and run it::

    pip install tox
    tox

Limit the tests to a specific python version::

    tox -e py27

Conventions
-----------

Onegov Foundation follows PEP8 as close as possible. To test for it run::

    tox -e pep8

Onegov Foundation uses `Semantic Versioning <http://semver.org/>`_

Build Status
------------

.. image:: https://travis-ci.org/OneGov/onegov.foundation.png
  :target: https://travis-ci.org/OneGov/onegov.foundation
  :alt: Build Status

Coverage
--------

.. image:: https://coveralls.io/repos/OneGov/onegov.foundation/badge.png?branch=master
  :target: https://coveralls.io/r/OneGov/onegov.foundation?branch=master
  :alt: Project Coverage

Latests PyPI Release
--------------------
.. image:: https://pypip.in/v/onegov.foundation/badge.png
  :target: https://crate.io/packages/onegov.foundation
  :alt: Latest PyPI Release

License
-------
onegov.foundation is released under GPLv2
